@@ -16,6 +16,7 @@
 #   License along with this library; if not, write to the Free Software
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+import codecs
 import os
 import xml.dom.minidom
 import xml.parsers.expat
@@ -23,7 +24,7 @@ from gi.repository import GMenu, GLib
 from Alacarte import util
 
 class MenuEditor(object):
-    def __init__(self, name=os.environ['XDG_MENU_PREFIX'] + 'applications.menu'):
+    def __init__(self, name=os.environ.get('XDG_MENU_PREFIX', '') + 'applications.menu'):
         self.name = name
 
         self.tree = GMenu.Tree.new(name, GMenu.TreeFlags.SHOW_EMPTY|GMenu.TreeFlags.INCLUDE_EXCLUDED|GMenu.TreeFlags.INCLUDE_NODISPLAY|GMenu.TreeFlags.SHOW_ALL_SEPARATORS|GMenu.TreeFlags.SORT_DISPLAY_NAME)
@@ -48,9 +49,8 @@ class MenuEditor(object):
         self.load()
 
     def save(self):
-        fd = open(self.path, 'w')
-        fd.write(self.dom.toprettyxml())
-        fd.close()
+        with codecs.open(self.path, 'w', 'utf8') as f:
+            f.write(self.dom.toprettyxml())
 
     def restoreToSystem(self):
         self.restoreTree(self.tree.get_root_directory())
@@ -259,9 +259,8 @@ class MenuEditor(object):
 
         contents, length = keyfile.to_data()
 
-        f = open(out_path, 'w')
-        f.write(contents)
-        f.close()
+        with codecs.open(out_path, 'w', 'utf8') as f:
+            f.write(contents)
 
         self.addItem(new_parent, file_id, dom)
         self.positionItem(new_parent, ('Item', file_id), before, after)
@@ -400,9 +399,10 @@ class MenuEditor(object):
 
         contents, length = keyfile.to_data()
 
-        f = open(os.path.join(util.getUserItemPath(), file_id), 'w')
-        f.write(contents)
-        f.close()
+        path = os.path.join(util.getUserItemPath(), file_id)
+        with codecs.open(path, 'w', 'utf8') as f:
+            f.write(contents)
+
         return file_id
 
     def writeMenu(self, menu, **kwargs):
@@ -421,9 +421,9 @@ class MenuEditor(object):
 
         contents, length = keyfile.to_data()
 
-        f = open(os.path.join(util.getUserDirectoryPath(), file_id), 'w')
-        f.write(contents)
-        f.close()
+        path = os.path.join(util.getUserDirectoryPath(), file_id)
+        with codecs.open(path, 'w', 'utf8') as f:
+            f.write(contents)
         return file_id
 
     def getXmlNodesByName(self, name, element):
